==> java-client-8.3.0-sources.jar: io/appium/java_client/ios/options/simulator/SupportsCustomSslCertOption.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.appium.java_client.ios.options.simulator;

import io.appium.java_client.remote.options.BaseOptions;
import io.appium.java_client.remote.options.CanSetCapability;
import org.openqa.selenium.Capabilities;

import java.util.Optional;

public interface SupportsCustomSslCertOption<T extends BaseOptions<T>> extends
        Capabilities, CanSetCapability<T> {
    String CUSTOM_SSLCERT_OPTION = "customSSLCert";

    /**
     * Adds a root SSL certificate to IOS Simulator.
     * The certificate content must be provided in PEM format.
     *
     * @param cert Certificate content in PEM format.
     * @return self instance for chaining.
     */
    default T setCustomSSLCert(String cert) {
        return amend(CUSTOM_SSLCERT_OPTION, cert);
    }

    /**
     * Get the SSL certificate content.
     *
     * @return Certificate content.
     */
    default Optional<String> setCustomSSLCert() {
        return Optional.ofNullable((String) getCapability(CUSTOM_SSLCERT_OPTION));
    }
}

==> java-client-8.6.0-sources.jar: io/appium/java_client/ios/options/simulator/SupportsCustomSslCertOption.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.appium.java_client.ios.options.simulator;

import io.appium.java_client.remote.options.BaseOptions;
import io.appium.java_client.remote.options.CanSetCapability;
import org.openqa.selenium.Capabilities;

import java.util.Optional;

public interface SupportsCustomSslCertOption<T extends BaseOptions<T>> extends
        Capabilities, CanSetCapability<T> {
    String CUSTOM_SSLCERT_OPTION = "customSSLCert";

    /**
     * Adds a root SSL certificate to IOS Simulator.
     * The certificate content must be provided in PEM format.
     *
     * @param cert Certificate content in PEM format.
     * @return self instance for chaining.
     */
    default T setCustomSSLCert(String cert) {
        return amend(CUSTOM_SSLCERT_OPTION, cert);
    }

    /**
     * Get the SSL certificate content.
     *
     * @deprecated use {@link SupportsCustomSslCertOption#getCustomSSLCert()} instead
     */
    @Deprecated
    default Optional<String> setCustomSSLCert() {
        return getCustomSSLCert();
    }

    /**
     * Get the SSL certificate content.
     *
     * @return Certificate content.
     */
    default Optional<String> getCustomSSLCert() {
        return Optional.ofNullable((String) getCapability(CUSTOM_SSLCERT_OPTION));
    }
}
